@@ -2,7 +2,7 @@
 # this repository contains the full copyright notices and license terms.
 from decimal import Decimal
 
-from sql import Literal, Null
+from sql import Literal, Null, Cast
 from sql.aggregate import Sum
 from sql.conditionals import Coalesce
 
@@ -90,8 +90,6 @@ class Party:
             return result
         company_id = user.company.id
 
-        line_query, _ = MoveLine.query_get(line)
-
         amount = Sum(Coalesce(line.debit, 0) - Coalesce(line.credit, 0))
         for name in names:
             code = name
@@ -110,7 +108,6 @@ class Party:
                             & (account.kind == code)
                             & (line.reconciliation == Null)
                             & (account.company == company_id)
-                            & line_query
                             & party_where
                             & today_where
                             & (account.kind == code)),
@@ -149,9 +146,14 @@ class Party:
             today_query = ((line.maturity_date <= Date.today())
                 | (line.maturity_date == Null))
 
-        line_query, _ = MoveLine.query_get(line)
         Operator = fields.SQL_OPERATORS[clause[1]]
 
+        # Need to cast numeric for sqlite
+        type_ = MoveLine.debit.sql_type().base
+        amount = Cast(
+            Sum(Coalesce(line.debit, 0) - Coalesce(line.credit, 0)),
+            type_)
+        value = Cast(Literal(Decimal(clause[2] or 0)), type_)
         query = line.join(account, condition=account.id == line.account
                 ).select(line.party,
                     where=account.active
@@ -159,9 +161,7 @@ class Party:
                     & (line.party != Null)
                     & (line.reconciliation == Null)
                     & (account.company == company_id)
-                    & line_query & today_query,
+                    & today_query,
                     group_by=line.party,
-                    having=Operator(Sum(Coalesce(line.debit, 0)
-                            - Coalesce(line.credit, 0)),
-                        Decimal(clause[2] or 0)))
+                    having=Operator(amount, value))
         return [('id', 'in', query)]
